@@ -1,19 +1,15 @@
 use strict;
 use warnings;
-package Test::Kwalitee;
-BEGIN {
-  $Test::Kwalitee::AUTHORITY = 'cpan:CHROMATIC';
-}
-# git description: v1.21-3-ga55ecda
-$Test::Kwalitee::VERSION = '1.22';
+package Test::Kwalitee; # git description: v1.22-21-gf56ea80
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Test the Kwalitee of a distribution before you release it
 # KEYWORDS: testing tests kwalitee CPANTS quality lint errors critic
-# vim: set ts=8 sw=4 tw=78 et :
 
-use Cwd;
+our $VERSION = '1.23';
+
+use Cwd ();
 use Test::Builder 0.88;
 use Module::CPANTS::Analyse 0.92;
-use namespace::clean;
 
 use parent 'Exporter';
 our @EXPORT_OK = qw(kwalitee_ok);
@@ -62,7 +58,7 @@ sub kwalitee_ok
     # MCA has a patch to add 'needs_tarball', 'no_build' as flags
     my @skip_flags = qw(is_extra is_experimental needs_db);
 
-    my $basedir = cwd;
+    my $basedir = Cwd::cwd;
 
     my $analyzer = Module::CPANTS::Analyse->new({
         distdir => $basedir,
@@ -141,13 +137,15 @@ Test::Kwalitee - Test the Kwalitee of a distribution before you release it
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
 In a separate test file:
 
   use Test::More;
+  use strict;
+  use warnings;
   BEGIN {
       plan skip_all => 'these tests are for release candidate testing'
           unless $ENV{RELEASE_TESTING};
@@ -218,7 +216,7 @@ However, this calling path is still available, e.g.:
 The list of each available metric currently available on your
 system can be obtained with the C<kwalitee-metrics> command (with
 descriptions, if you pass C<--verbose> or C<-v>, but
-as of Test::Kwalitee 1.19 and L<Module::CPANTS::Analyse> 0.93_01, the tests include:
+as of L<Module::CPANTS::Analyse> 0.97_03, the tests include:
 
 =over 4
 
@@ -281,19 +279,9 @@ Does the distribution have tests?
 
 =item *
 
-meta_yml_conforms_to_known_spec
+manifest_matches_dist
 
-=for stopwords recognised
-
-Does META.yml conform to any recognised META.yml specification?
-(For specs see
-L<http://module-build.sourceforge.net/META-spec-current.html>)
-
-=item *
-
-meta_yml_is_parsable
-
-Can the F<META.yml> be parsed?
+Do the F<MANIFEST> and distribution contents match?
 
 =item *
 
@@ -310,6 +298,22 @@ Can the F<META.json> be parsed?
 
 =item *
 
+meta_yml_conforms_to_known_spec
+
+=for stopwords recognised
+
+Does META.yml conform to any recognised META.yml specification?
+(For specs see
+L<http://module-build.sourceforge.net/META-spec-current.html>)
+
+=item *
+
+meta_yml_is_parsable
+
+Can the F<META.yml> be parsed?
+
+=item *
+
 no_broken_auto_install
 
 Is the distribution using an old version of L<Module::Install>? Versions of
@@ -379,6 +383,17 @@ L<Dist::Zilla::App::Command::kwalitee>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Kwalitee>
+(or L<bug-Test-Kwalitee@rt.cpan.org|mailto:bug-Test-Kwalitee@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/perl-qa.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#perl> on C<irc.perl.org>|irc://irc.perl.org/#perl-qa>.
+
 =head1 AUTHORS
 
 =over 4
@@ -393,26 +408,23 @@ Karen Etheridge <ether@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2005 by chromatic.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Gavin Sherlock David Steinbrunner Nathan Haigh Zoffix Znet Kenichi Ishigaki
+=for stopwords David Steinbrunner Gavin Sherlock Kenichi Ishigaki Nathan Haigh Zoffix Znet Daniel Perrett
 
 =over 4
 
 =item *
 
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
 Gavin Sherlock <sherlock@cpan.org>
 
 =item *
 
-David Steinbrunner <dsteinbrunner@pobox.com>
+Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
 
@@ -424,8 +436,15 @@ Zoffix Znet <cpan@zoffix.com>
 
 =item *
 
-Kenichi Ishigaki <ishigaki@cpan.org>
+Daniel Perrett <perrettdl@googlemail.com>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005 by chromatic.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
